biosimulators_utils.viz.vega.ginml package — BioSimulators utils 0.1.154 documentation

# biosimulators_utils.viz.vega.ginml package

## Submodules

## biosimulators_utils.viz.vega.ginml.core module

Utility for converting activity flow diagrams from GINsim Markup Language (GINML) to Vega format

Author

  Andrew Freiburger <afreiburger@uvic.ca>

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2021-07-23

Copyright

  2021, Center for Reproducible Biomedical Modeling

License

  MIT

biosimulators_utils.viz.vega.ginml.core.ginml_to_vega(node_values_data_set, ginml_filename, vega_filename, optimum_nodes_quantity=18, edge_x_value_adjustment=0, edge_y_value_adjustment=45, signal_height=65, signal_padding=10, indent=2)

  Convert an activity flow diagram from GINsim Markup Language (GINML) format to Vega format.

  Parameters

    - node_values_data_set (`dict`) –

      Vega data set with the predicted values of each node. The dictionary should have one of the following schemas

      - Contain a key `values` whose value is a list of the predicted node values. Each item of the list should be a dictionary with two keys

        > - `label`: value should be the SBML-qual identifier of the corresponding node

        > - `values`: array of the predicted value of the species at each time step

      - Contain a key `url` whose value is a URL where the predicted values can be retrieved in JSON format. The data should be in the same format outlined above.

      - Contain a key `sedmlUri` whose value is an array which contains two elements that indicate

        > - The location of the SED-ML file (within its parent COMBINE/OMEX archive) which will produce the predictions for the visualization

        > - The id of the SED-ML report which will contain the predictions for the visualization

    - ginml_filename (`str`) – path to the visualization in GINML format

    - vega_filename (`str`) – path to save the visualization in Vega format

    - optimum_nodes_quantity (`int`) –

    - edge_x_value_adjustment (`int`) –

    - edge_y_value_adjustment (`int`) –

    - signal_height (`int`) –

    - signal_padding (`int`) –

    - indent (`int` or `None`, optional) – indentation